@@ -31,8 +31,9 @@ Steam
    <fr_BE>Jeux fonctionnant avec Steam</fr_BE>
    <fr>Jeux fonctionnant avec Steam</fr>
    <gl_ES>Xogos da Plataforma Steam</gl_ES>
+   <gu>Steam powered games</gu>
    <he_IL>Steam powered games</he_IL>
-   <hi>Steam powered games</hi>
+   <hi>स्टीम चलित खेल</hi>
    <hr>Steam powered games</hr>
    <hu>Steam powered games</hu>
    <id>Steam powered games</id>
@@ -41,6 +42,7 @@ Steam
    <ja>Steam で動くゲーム</ja>
    <kk>Steam powered games</kk>
    <ko>Steam powered games</ko>
+   <ku>Steam powered games</ku>
    <lt>Steam powered games</lt>
    <mk>Steam powered games</mk>
    <mr>Steam powered games</mr>
@@ -48,6 +50,7 @@ Steam
    <nb>Steam-baserte spill</nb>
    <nl_BE>Steam powered games</nl_BE>
    <nl>Steam aangedreven spellen</nl>
+   <or>Steam powered games</or>
    <pl>Gry na Steam</pl>
    <pt_BR>Jogos da Plataforma Steam</pt_BR>
    <pt>Jogos da Plataforma Steam</pt>
@@ -55,7 +58,8 @@ Steam
    <ru>Платформа цифрового распространения игр</ru>
    <sk>Steam powered games</sk>
    <sl>Steam igre</sl>
-   <sq>Steam powered games</sq>
+   <so>Steam powered games</so>
+   <sq>Lojëra të bazuara në Steam</sq>
    <sr>Steam powered games</sr>
    <sv>Steam-drivna spel</sv>
    <th>Steam powered games</th>
